# -*- coding: utf-8 -*-
# @Project: 芒果测试平台# @Description:
# @Time   : 2023-03-07 8:24
# @Author : 毛鹏
import random
from datetime import date, timedelta, datetime

import time
from faker import Faker


class RandomTimeData:
    """ 随机时间类型测试数据 """
    faker = Faker(locale='zh_CN')

    @classmethod
    def time_now_ymdhms(cls) -> str:
        """当前年月日时分秒"""
        localtime = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
        return localtime

    @classmethod
    def time_now_ymd(cls) -> str:
        """当前年月日"""
        localtime = time.strftime("%Y-%m-%d", time.localtime())
        return localtime

    @classmethod
    def get_time_for_min(cls, **kwargs) -> int:
        """获取几分钟后的时间戳 参数：data"""
        minute = kwargs.get('data')
        if minute is None:
            minute = 1
        return int(time.time() + 60 * int(minute)) * 1000

    @classmethod
    def time__random_ymdhms(cls):
        """随机年月日时分秒"""
        return cls.faker.date_time()

    @classmethod
    def time_random_ymd(cls):
        """随机年月日"""
        return cls.faker.date_this_year()

    @classmethod
    def time_random_hms(cls):
        """随机的时分秒"""
        hours = random.randint(0, 23)
        minutes = random.randint(0, 59)
        seconds = random.randint(0, 59)
        random_time = f"{hours:02d}:{minutes:02d}:{seconds:02d}"  # 格式化为 HH:MM:SS
        return random_time

    @classmethod
    def time_random_year(cls):
        """获取随机年份"""
        return cls.faker.year()

    @classmethod
    def time_random_month(cls):
        """获取随机月份"""
        return cls.faker.month()

    @classmethod
    def time_random_date(cls):
        """获取随机日期"""
        return cls.faker.date()

    @classmethod
    def time_now_int(cls) -> int:
        """获取当前时间戳整形"""
        return int(time.time()) * 1000

    @classmethod
    def time_today_weekday(cls):
        """今天是周几"""
        weekdays = ["周一", "周二", "周三", "周四", "周五", "周六", "周日"]
        weekday = date.today().weekday()
        return weekdays[weekday]

    @classmethod
    def time_before_time(cls, **kwargs):
        """当今日之前的日期"""
        days = kwargs.get('data')
        if days is None:
            days = 1
        yesterday = datetime.now() - timedelta(days=int(days))
        yesterday_str = yesterday.strftime('%Y-%m-%d')
        return yesterday_str

    @classmethod
    def time_stamp(cls, **kwargs) -> int:
        """几分钟后的时间戳"""
        minute = kwargs.get('data')
        if minute is None:
            minute = 1
        return int(time.time() + 60 * int(minute)) * 1000

    @classmethod
    def time_next_minute(cls, **kwargs) -> str:
        """几分钟后的年月日时分秒 参数：分钟"""
        minute = kwargs.get('data')
        if minute is None:
            minute = 1
        future_time = datetime.now() + timedelta(minutes=int(minute))
        return future_time.strftime('%Y-%m-%d %H:%M:%S')

    @classmethod
    def time_future_datetime(cls):
        """未来的随机年月日时分秒"""
        return cls.faker.future_datetime()

    @classmethod
    def time_future_date(cls):
        """未来的随机年月日"""
        return cls.faker.future_date()

    @classmethod
    def time_by_type(cls, **kwargs) -> str:
        """当前年月日时分秒并返回指定格式"""
        types = str(kwargs.get('data'))
        data_type = ''
        if types is None or types == '0':
            data_type = '%Y-%m-%d %H:%M:%S'
        elif types == '1':
            data_type = '%Y-%m-%d %H:%M'
        elif types == '2':
            data_type = '%Y-%m-%d %H'
        elif types == '3':
            data_type = '%Y-%m-%d'
        elif types == '4':
            data_type = '%Y-%m'
        elif types == '5':
            data_type = '%Y'
        now_time = datetime.now().strftime(data_type)
        return now_time

    @classmethod
    def time_today_date(cls):
        """获取今日0点整时间"""
        _today = date.today().strftime("%Y-%m-%d") + " 00:00:00"
        return str(_today)

    @classmethod
    def time_after_week(cls):
        """获取一周后12点整的时间"""
        _time_after_week = (date.today() + timedelta(days=+6)).strftime("%Y-%m-%d") + " 00:00:00"
        return _time_after_week

    @classmethod
    def time_after_month(cls):
        """获取30天后的12点整时间"""
        _time_after_week = (date.today() + timedelta(days=+30)).strftime("%Y-%m-%d") + " 00:00:00"
        return _time_after_week

    @classmethod
    def time_day_reduce(cls, **kwargs) -> int:
        """获取今日日期的数字，传参可以减N"""
        types = kwargs.get('data')
        today = datetime.today()
        if types:
            return today.day - int(types)
        else:
            return today.day

    @classmethod
    def time_day_plus(cls, **kwargs) -> int:
        """获取今日日期的数字，传参可以加N"""
        types = kwargs.get('data')
        today = datetime.today()
        if types:
            return today.day + int(types)
        else:
            return today.day

    @classmethod
    def time_now_hms(cls):
        """时分秒"""
        return datetime.now().strftime("%H:%M:%S")

    @classmethod
    def time_cron_time(cls, **kwargs) -> str:
        """秒级cron表达式"""
        time_parts = kwargs.get('data').split()
        seconds = int(time_parts[0])
        minutes = int(time_parts[1])
        hours = int(time_parts[2])
        current_date = datetime.now().date()
        date_obj = datetime(year=current_date.year,
                            month=current_date.month,
                            day=current_date.day,
                            hour=hours,
                            minute=minutes,
                            second=seconds)

        time_str_result = date_obj.strftime("%H:%M:%S")
        return time_str_result

    @classmethod
    def time_next_minute_cron(cls, **kwargs):
        """按周重复的cron表达式"""
        if kwargs.get('data'):
            minutes = int(kwargs.get('data'))
        else:
            minutes = 1
        now = datetime.now() + timedelta(minutes=minutes)
        second = f"{now.second:02d}"  # 格式化为两位数
        minute = f"{now.minute:02d}"  # 格式化为两位数
        hour = f"{now.hour:02d}"  # 格式化为两位数
        day = "?"  # 日用问号表示不指定
        month = "*"  # 月用星号表示每个月
        weekday = str(date.today().weekday() + 2)
        return f"{second} {minute} {hour} {day} {month} {weekday}"


if __name__ == '__main__':
    test = RandomTimeData.time_after_week()
    print(test)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台# @Description:
# @Time   : 2023-09-09 23:17
# @Author : 毛鹏
from assertpy import assert_that
from deepdiff import DeepDiff

from ..decorator import sync_method_callback
from ..models import MethodModel


def _assert_that(actual):
    if actual is None:
        raise AssertionError(f"实际值不能为 None ，可能是在获取实际值的时候就失败了！")
    return assert_that(actual)


class WhatIsItAssertion:
    """是什么"""

    @staticmethod
    @sync_method_callback('ass', '是什么', 0, [
        MethodModel(f='actual', d=True)])
    def p_is_not_none(actual):
        """不是null"""
        try:
            assert_that(actual).is_not_none()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不是null') from e

    @staticmethod
    @sync_method_callback('ass', '是什么', 1, [
        MethodModel(f='actual', d=True)])
    def p_is_none(actual):
        """是null"""
        try:
            assert_that(actual).is_none()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是null') from e

    @staticmethod
    @sync_method_callback('ass', '是什么', 2, [
        MethodModel(f='actual', d=True)])
    def p_is_empty(actual):
        """是空字符串"""
        try:
            _assert_that(actual).is_empty()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是空字符串') from e

    @staticmethod
    @sync_method_callback('ass', '是什么', 3, [
        MethodModel(f='actual', d=True)])
    def p_is_not_empty(actual):
        """不是空符串"""
        try:
            _assert_that(actual).is_not_empty()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不是空符串') from e

    @staticmethod
    @sync_method_callback('ass', '是什么', 4, [
        MethodModel(f='actual', d=True)])
    def p_is_false(actual):
        """是false"""
        try:
            assert_that(actual).is_false()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是false') from e

    @staticmethod
    @sync_method_callback('ass', '是什么', 5, [
        MethodModel(f='actual', d=True)])
    def p_is_true(actual):
        """是true"""
        try:
            assert_that(actual).is_true()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是true') from e

    @staticmethod
    @sync_method_callback('ass', '是什么', 6, [
        MethodModel(f='actual', d=True)])
    def p_is_alpha(actual):
        """是字母"""
        try:
            _assert_that(actual).is_alpha()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是字母') from e

    @staticmethod
    @sync_method_callback('ass', '是什么', 7, [
        MethodModel(f='actual', d=True)])
    def p_is_digit(actual):
        """是数字"""
        try:
            _assert_that(actual).is_digit()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是数字') from e


class WhatIsEqualToAssertion:
    """等于什么"""

    @staticmethod
    @sync_method_callback('ass', '等于什么', 0, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_is_equal_to(actual: str, expect: str):
        """等于expect"""
        try:
            _assert_that(actual).is_equal_to(expect),
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '等于什么', 1, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_is_not_equal_to(actual: str, expect: str):
        """不等于expect"""
        try:
            _assert_that(actual).is_not_equal_to(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '等于什么', 2, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_is_length(actual: str, expect: str):
        """长度等于expect"""
        try:
            _assert_that(actual).is_length(int(expect))
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '等于什么', 3, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_sum_equal_expect(actual: list, expect: str):
        """长度等于expect"""
        try:
            _assert_that(sum(actual)).is_equal_to(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e


class ContainAssertion:
    """包含什么"""

    @staticmethod
    @sync_method_callback('ass', '包含什么', 0, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_contains(actual: str, expect: str):
        """包含expect"""
        try:
            _assert_that(actual).contains(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '包含什么', 1, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_is_equal_to_ignoring_case(actual: str, expect: str):
        """忽略大小写等于expect"""
        try:
            _assert_that(actual).is_equal_to_ignoring_case(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '包含什么', 2, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_contains_ignoring_case(actual: str, expect: str):
        """包含忽略大小写expect"""
        try:
            _assert_that(actual).contains_ignoring_case(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '包含什么', 3, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_contains_only(actual: str, expect: str):
        """仅包含expect"""
        try:
            _assert_that(actual).contains_only(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '包含什么', 4, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_does_not_contain(actual: str, expect: str):
        """不包含expect"""
        try:
            _assert_that(actual).does_not_contain(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e


class MatchingAssertion:
    """匹配什么"""

    @staticmethod
    @sync_method_callback('ass', '匹配什么', 0, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_in_dict(actual: dict, expect: dict):
        """JSON匹配"""
        filtered_actual = filter_dict(dict(actual), dict(expect))
        diff = DeepDiff(filtered_actual, expect, ignore_order=True)
        assert not diff, f'实际={actual}, 预期={expect}'

    @staticmethod
    @sync_method_callback('ass', '匹配什么', 1, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_is_in(actual: str, expect: str):
        """在expect里面"""
        try:
            _assert_that(actual).is_in(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '匹配什么', 2, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_is_not_in(actual: str, expect: str):
        """不在expect里面"""
        try:
            _assert_that(actual).is_not_in(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '匹配什么', 3, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_starts_with(actual: str, expect: str):
        """以expect开头"""
        try:
            _assert_that(actual).starts_with(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '匹配什么', 4, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_ends_with(actual: str, expect: str):
        """以expect结尾"""
        try:
            _assert_that(actual).ends_with(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '匹配什么', 5, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_matches(actual: str, expect: str):
        """正则匹配等于expect"""
        try:
            _assert_that(actual).matches(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('ass', '匹配什么', 6, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_does_not_match(actual: str, expect: str):
        """正则不匹配expect"""
        try:
            _assert_that(actual).does_not_match(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e


def filter_dict(actual: dict, expect: dict) -> dict:
    filtered = {}
    for key in expect.keys():
        if key in actual:
            if isinstance(expect[key], dict):
                filtered[key] = filter_dict(actual[key], expect[key])
            elif isinstance(expect[key], list) and isinstance(actual[key], list):
                filtered[key] = []
                for item in actual[key]:
                    if isinstance(item, dict):
                        filtered_item = filter_dict(item, expect[key][0])
                        filtered[key].append(filtered_item)
                    else:
                        filtered[key].append(item)
            else:
                filtered[key] = actual[key]
    return filtered


class PublicAssertion(WhatIsItAssertion, ContainAssertion, MatchingAssertion, WhatIsEqualToAssertion):
    pass


if __name__ == '__main__':
    PublicAssertion.p_is_equal_to('1', '2')



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 邮箱通知封装
# @Time   : 2022-11-04 22:05
# @Author : 毛鹏
import smtplib
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from socket import gaierror

from ..exceptions import MangoToolsError
from ..exceptions.error_msg import ERROR_MSG_0016
from ..models import EmailNoticeModel, TestReportModel


class EmailSend:

    def __init__(self, notice_config: EmailNoticeModel, test_report: TestReportModel = None, domain_name: str = None,
                 content: str = None):
        self.test_report = test_report
        self.notice_config = notice_config
        self.domain_name = domain_name
        self.content = content

    def send_main(self) -> None:
        if self.test_report.test_suite_id:
            content = f"""
            各位同事, 大家好:
                测试套ID：{self.test_report.test_suite_id}任务执行完成，执行结果如下:
                用例运行总数: {self.test_report.case_sum} 个
                通过用例个数: {self.test_report.success} 个
                失败用例个数: {self.test_report.fail} 个
                异常用例个数: {self.test_report.warning} 个
                跳过用例个数: 暂不统计 个
                成  功   率: {self.test_report.success_rate} %
    
    
            **********************************
            芒果自动化平台地址：{self.domain_name}
            详细情况可前往芒果自动化平台查看，非相关负责人员可忽略此消息。谢谢！
            """
        else:
            content = f"""
            各位同事, 大家好:
                用例运行总数: {self.test_report.case_sum} 个
                通过用例个数: {self.test_report.success} 个
                失败用例个数: {self.test_report.fail} 个
                异常用例个数: {self.test_report.warning} 个
                跳过用例个数: 暂不统计 个
                成  功   率: {self.test_report.success_rate} %


            **********************************
            芒果自动化平台地址：{self.domain_name}
            详细情况可前往芒果自动化平台查看，非相关负责人员可忽略此消息。谢谢！
            """
        self.send_mail(self.notice_config.send_list, f'【芒果测试平台通知】', content)

    def send_mail(self, user_list: list, sub: str, content: str, ) -> None:
        try:
            user = f"MangoTestPlatform <{self.notice_config.send_user}>"
            msg = MIMEMultipart()
            msg['From'] = user
            msg['To'] = ";".join(user_list)
            msg['Subject'] = sub
            msg.attach(MIMEText(self.content if self.content else content, 'plain'))
            with smtplib.SMTP(self.notice_config.email_host, ) as server:
                server.starttls()
                server.login(self.notice_config.send_user, self.notice_config.stamp_key)
                server.sendmail(user, user_list, msg.as_string())
                server.quit()
        except (gaierror, smtplib.SMTPServerDisconnected):
            raise MangoToolsError(*ERROR_MSG_0016)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台# @Description:
# @Time   : 2023/4/6 13:36
# @Author : 毛鹏

from ..assertion._custom_assertion import CustomAssertion
from ..assertion._public_assertion import WhatIsItAssertion, ContainAssertion, MatchingAssertion, \
    WhatIsEqualToAssertion, PublicAssertion
from ..assertion._sql_assertion import SqlAssertion
import sys

python_version = sys.version_info
if f"{python_version.major}.{python_version.minor}" != "3.10":
    raise Exception("必须使用>Python3.10.4")


class Assertion(WhatIsItAssertion, ContainAssertion, MatchingAssertion, WhatIsEqualToAssertion):
    pass


__all__ = [
    'Assertion',
    'CustomAssertion',
    'SqlAssertion',
    'PublicAssertion',
]



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台# @Description: 随机数据封装
# @Time   : 2022-11-04 22:05
# @Author : 毛鹏
import random

import time
from faker import Faker


class RandomNumberData:
    """ 随机的数字类型测试数据 """
    faker = Faker(locale='zh_CN')

    @classmethod
    def randint(cls, **kwargs):
        """随机的范围数，传入：left，right"""
        data = kwargs.get('data')
        if data:
            left = data.get('left', 2000)
        else:
            left = 2000
        if data:
            right = data.get('left', 2500)
        else:
            right = 2500
        return random.randint(left, right)

    @classmethod
    def number_time_5(cls):
        """获取基于当前时间戳的随机五位数"""
        s = int(time.time())
        s = str(s)
        return s[5:len(s)]

    @classmethod
    def number_random_0_9(cls) -> int:
        """0-9的随机数"""
        _data = random.randint(0, 9)
        return _data

    @classmethod
    def number_random_0_5(cls) -> int:
        """0-9的随机数"""
        _data = random.randint(0, 5)
        return _data

    @classmethod
    def number_random_10_99(cls) -> int:
        """10-99的随机数"""
        _data = random.randint(10, 99)
        return _data

    @classmethod
    def number_random_100_999(cls) -> int:
        """100-999的随机数"""
        _data = random.randint(100, 999)
        return _data

    @classmethod
    def number_random_0_5000(cls) -> int:
        """0-5000的随机数"""
        _data = random.randint(0, 5000)
        return _data

    @classmethod
    def number_random_float(cls):
        """小数"""
        return random.random()

    @classmethod
    def number_random_two_float(cls):
        """随机两位小数"""
        return round(random.random(), 2)

    @classmethod
    def number_random_1000_two_float(cls):
        """1000以内的随机两位小数"""
        return cls.number_random_100_999() + round(random.random(), 2)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2023-11-08 15:48
# @Author : 毛鹏
from typing import Optional, Any

from pydantic import BaseModel

class MethodModel(BaseModel):
    f: str
    p: str | None = None
    d: bool = False
    v: Any = None


class ResponseModel(BaseModel):
    response_time: float
    headers: dict
    status_code: int
    text: str
    json_data: dict | str | None


class MysqlConingModel(BaseModel):
    host: str
    port: int
    user: str
    password: str | None = None
    database: str | None = None


class EmailNoticeModel(BaseModel):
    send_user: str
    email_host: str
    stamp_key: str
    send_list: list


class TestReportModel(BaseModel):
    test_suite_id: int | None = None
    project_id: int
    project_name: str
    test_environment: str
    case_sum: int
    success: int
    success_rate: float
    warning: int
    fail: int
    execution_duration: int | float
    test_time: str


class WeChatNoticeModel(BaseModel):
    webhook: str


class FunctionModel(BaseModel):
    label: str
    value: str
    parameter: dict[str, Optional[str]]


class ClassMethodModel(BaseModel):
    value: str
    label: str
    children: list[FunctionModel]



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2023-11-20 9:47
# @Author : 毛鹏

from ..database import MysqlConnect
from ..decorator import sync_method_callback
from ..models import MethodModel


class SqlAssertion:
    """sql断言"""
    mysql_connect: MysqlConnect = None

    @staticmethod
    @sync_method_callback('ass', 'sql断言', 0, [
        MethodModel(f='sql', p='请输入sql语句，确保只会查出一个值', d=True),
        MethodModel(f='expect', p='期望的json', d=True), ])
    async def sql_is_equal(sql: str, expect: list[dict]):
        """值相等"""
        result = SqlAssertion.mysql_connect.condition_execute(sql)
        assert all(dict2 in result for dict2 in expect), f'实际={result}, 预期=列表个数相等'


if __name__ == '__main__':
    _sql = "SELECT id,`name`,`status` FROM `project`;"
    _expect = [{'id': 2, 'name': '1CDXP', 'status': 1}, {'id': 5, 'name': 'AIGC', 'status': 1},
               {'id': 10, 'name': 'DESK', 'status': 1}, {'id': 11, 'name': 'AIGC-SaaS', 'status': 1}]



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time: 2023-07-16 15:17
# @Author : 毛鹏


class MangoToolsError(Exception):

    def __init__(self, code: int, msg: str, value: tuple = None):
        self.msg = msg.format(*value) if value else msg
        self.code = code

    def __str__(self):
        return f"[{self.code}] {self.msg}"



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台# @Description:
# @Time   : 2023-09-09 23:17
# @Author : 毛鹏
import sys

from ..models._models import *

python_version = sys.version_info
if f"{python_version.major}.{python_version.minor}" != "3.10":
    raise Exception("必须使用>Python3.10.4")
__all__ = [
    'MysqlConingModel',
    'FunctionModel',
    'TestReportModel',
    'ResponseModel',
    'EmailNoticeModel',
    'WeChatNoticeModel',
    'ClassMethodModel',
    'MethodModel'
]



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台# @Description: 随机数据封装
# @Time   : 2022-11-04 22:05
# @Author : 毛鹏
import random
import string
import uuid

from faker import Faker

from ..exceptions import MangoToolsError
from ..exceptions.error_msg import ERROR_MSG_0006


class RandomStringData:
    """ 随机的字符类型测试数据 """
    faker = Faker(locale='zh_CN')

    @classmethod
    def str_uuid(cls):
        """随机的UUID，长度36"""
        return str(uuid.uuid4())

    @classmethod
    def str_city(cls):
        """获取城市"""
        return cls.faker.city()

    @classmethod
    def str_country(cls):
        """获取国家"""
        return cls.faker.country()

    @classmethod
    def str_province(cls):
        """获取省份"""
        return cls.faker.province()

    @classmethod
    def str_pystr(cls):
        """生成英文的字符串"""
        return cls.faker.pystr()

    @classmethod
    def str_word(cls):
        """生成词语"""
        return cls.faker.word()

    @classmethod
    def str_text(cls):
        """生成一篇文章"""
        return cls.faker.text()

    @classmethod
    def str_random_string(cls, **kwargs):
        """随机字母数字,可传入数字获取指定位数字符串，默认为10"""
        try:
            data = kwargs.get('data')
            if data is None:
                data = 10
            length = int(data)
        except ValueError:
            raise MangoToolsError(*ERROR_MSG_0006)
        characters = string.ascii_letters + string.digits
        random_string = ''.join(random.choice(characters) for _ in range(length))
        return random_string



from setuptools import setup, find_packages

__version__ = '1.0.27'

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name='mangotools',
    version=__version__,
    description='测试工具',
    long_description=long_description,
    package_data={
        'mangotools': [
            'mangos/pyarmor_runtime_linux/pyarmor_runtime_000000/pyarmor_runtime.so',
            'mangos/pyarmor_runtime_windows/pyarmor_runtime_000000/pyarmor_runtime.pyd',
        ]
    },
    author='毛鹏',
    author_email='729164035@qq.com',
    url='https://gitee.com/mao-peng/testkit',
    packages=find_packages(),
    install_requires=[
        'aiomysql==0.2.0',
        'PyMySQL==1.1.1',
        'jsonpath==0.82.2',
        'cachetools==5.3.1',
        'Faker==24.1.0',
        'diskcache==5.6.3',
        'pydantic==2.9.2',
        'colorlog==6.7.0',
        'pyarmor==9.0.6',
        'assertpy==1.1',
        'deepdiff==8.0.1',
        'requests==2.32.3'
    ],
    classifiers=[
        "Programming Language :: Python :: 3.10",
    ]
)

"""


python -m pip install --upgrade setuptools wheel
python -m pip install --upgrade twine

python setup.py check
python setup.py sdist bdist_wheel
twine upload --repository-url https://upload.pypi.org/legacy/ dist/*

"""



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-12-26 14:17
# @Author : 毛鹏
import inspect
import os
import socket

from .data_processor import ObtainRandomData
from .models import FunctionModel, ClassMethodModel


def root_path():
    """ 获取根路径 """
    path = os.path.dirname(__file__)
    return path


def ensure_path_sep(path: str) -> str:
    """兼容 windows 和 linux 不同环境的操作系统路径 """
    if "/" in path:
        path = os.sep.join(path.split("/"))

    if "\\" in path:
        path = os.sep.join(path.split("\\"))
    return path


def get_host_ip():
    """
    查询本机ip地址
    :return:
    """
    _s = None
    try:
        _s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        _s.connect(('8.8.8.8', 80))
        l_host = _s.getsockname()[0]
    finally:
        _s.close()

    return l_host


def class_methods(self) -> list[ClassMethodModel]:
    class_list = []
    for subclass in self.mro()[1:]:
        children = []
        for method_name in dir(subclass):
            if not method_name.startswith("__"):
                method = getattr(subclass, method_name)
                if callable(method):
                    doc = method.__doc__
                    signature = inspect.signature(method)
                    parameters = signature.parameters
                    param_dict = {}
                    for param in parameters.values():
                        if param.name != 'self':
                            param_dict[param.name] = ''
                    children.append(FunctionModel(
                        label=method_name + '()',
                        value=doc,
                        parameter=param_dict
                    ))

        if children:
            class_list.append(ClassMethodModel(label=subclass.__doc__, value=subclass.__name__, children=children))

    return class_list


def class_own_methods(self) -> list[FunctionModel]:
    methods = []
    for attr in dir(self):
        obj = getattr(self, attr)
        if (inspect.ismethod(obj) or inspect.isfunction(obj)) and obj.__qualname__.split('.')[
            0] == self.__name__:
            if attr != '__init__':
                doc = inspect.getdoc(obj)
                signature = inspect.signature(obj)
                parameters = signature.parameters
                param_dict = {}
                for param in parameters.values():
                    if param.name != 'self':
                        param_dict[param.name] = ''
                methods.append(FunctionModel(
                    label=doc,
                    value=attr,
                    parameter=param_dict
                ))
    return methods


if __name__ == '__main__':
    print([i.model_dump() for i in class_methods(ObtainRandomData)])



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-02-26 11:46
# @Author : 毛鹏
import os
import platform
from pathlib import Path

import sys

python_version = sys.version_info
if f"{python_version.major}.{python_version.minor}" != "3.10":
    raise Exception("必须使用>Python3.10.4")
system = platform.system().lower()
if system == "windows":
    runtime_path = os.path.join(os.path.dirname(__file__), "pyarmor_runtime_windows")
elif system == "linux":
    runtime_path = os.path.join(os.path.dirname(__file__), "pyarmor_runtime_linux")
elif system == "Darwin" or system == "darwin":
    runtime_path = os.path.join(os.path.dirname(__file__), "pyarmor_runtime_linux")
else:
    raise RuntimeError(f"Unsupported platform: {system}")

if runtime_path not in sys.path:
    sys.path.append(runtime_path)
runtime_sub_path = os.path.join(runtime_path, "pyarmor_runtime_000000")
if runtime_sub_path not in sys.path:
    sys.path.append(runtime_sub_path)


def _load_pyarmor():
    """加载PyArmor运行时，完全适配您的打包结构"""
    try:
        base_path = getattr(sys, '_MEIPASS', os.path.dirname(os.path.abspath(__file__)))
        base_path = Path(base_path)
        if getattr(sys, 'frozen', False):
            runtime_dir = base_path / "mangos" / (
                "pyarmor_runtime_windows" if sys.platform == "win32" else "pyarmor_runtime_linux"
            )
        else:
            runtime_dir = base_path / (
                "pyarmor_runtime_windows" if sys.platform == "win32" else "pyarmor_runtime_linux"
            )

        if not runtime_dir.exists():
            raise RuntimeError(
                f"PyArmor运行时目录不存在\n"
                f"最终搜索路径: {runtime_dir}\n"
                f"当前工作目录: {os.getcwd()}\n"
                f"系统路径: {sys.path}\n"
                f"_MEIPASS: {getattr(sys, '_MEIPASS', '未设置')}"
            )
        runtime_dir_str = str(runtime_dir)
        if runtime_dir_str not in sys.path:
            sys.path.insert(0, runtime_dir_str)
        runtime_sub_dir = runtime_dir / "pyarmor_runtime_000000"
        if not runtime_sub_dir.exists():
            raise RuntimeError(f"缺少PyArmor子运行时目录: {runtime_sub_dir}")

        if str(runtime_sub_dir) not in sys.path:
            sys.path.insert(0, str(runtime_sub_dir))

    except Exception as e:
        raise RuntimeError(f"初始化PyArmor运行时失败: {str(e)}")


_load_pyarmor()
try:
    from mango import Mango

    Mango.v(1)
except ImportError as e:
    raise RuntimeError(f"导入mango模块失败，请检查PyArmor运行时配置。错误详情: {str(e)}")

__all__ = ['Mango']
